@@ -8,11 +8,11 @@ from requests import HTTPError
 from fhir_cli import (
     DBT_SCHEMA,
     FHIR_COLUMN_NAME,
+    POSTGRES_DB,
     POSTGRES_HOST,
+    POSTGRES_PASSWORD,
     POSTGRES_PORT,
-    PROJECT_DB,
-    PROJECT_USER,
-    PROJECT_USER_PASSWORD,
+    POSTGRES_USER,
     log,
 )
 from fhir_cli.admin import Admin
@@ -57,6 +57,49 @@ class Cli:
         self.dbt = Dbt()
         self.admin = Admin()
 
+    @staticmethod
+    def link(source: str, target: str = None):
+        """Create a foreign schema from a schema of the source database
+
+        This command uses a foreign data wrapper to access data
+        stored in an external server. The module opens a connection and extracts
+        a database schema. Subsequently a user can import the data to the local
+        database by creating a table or a materialized view selecting from a
+        foreign table of a given schema.
+
+        Args:
+            source (str): the source schema
+            target (:obj:`str`, optional): the target schema. If not specified,
+            the target schema will take the name of the source schema.
+        """
+
+        if not target:
+            target = source
+
+        conn = connect(
+            host=POSTGRES_HOST,
+            dbname=POSTGRES_DB,
+            port=POSTGRES_PORT,
+            user=POSTGRES_USER,
+            password=POSTGRES_PASSWORD,
+        )
+
+        schema_stmt = sql.SQL("CREATE SCHEMA {target_schema}").format(
+            target_schema=sql.Identifier(target)
+        )
+        import_stmt = sql.SQL(
+            "IMPORT FOREIGN SCHEMA {source_schema} FROM SERVER source_server INTO {target_schema}"
+        ).format(
+            source_schema=sql.Identifier(source),
+            target_schema=sql.Identifier(target),
+        )
+        with conn.cursor() as curs:
+            curs.execute(schema_stmt)
+            curs.execute(import_stmt)
+            conn.commit()
+
+        conn.close()
+
     @staticmethod
     def validate(model: str, offset: int = 0, limit: int = 100):
         """Extract a fhir model row and validates the Fhir resource
@@ -69,10 +112,10 @@ class Cli:
         """
         conn = connect(
             host=POSTGRES_HOST,
-            dbname=PROJECT_DB,
+            dbname=POSTGRES_DB,
             port=POSTGRES_PORT,
-            user=PROJECT_USER,
-            password=PROJECT_USER_PASSWORD,
+            user=POSTGRES_USER,
+            password=POSTGRES_PASSWORD,
             cursor_factory=RealDictCursor,
             options=f"-c search_path={DBT_SCHEMA}",
         )
